import base64
from os import getenv
import pathlib

from dotenv import load_dotenv
import filetype
from sendgrid import SendGridAPIClient
from sendgrid.helpers.mail import (
    Mail,
    Attachment,
    FileContent,
    FileName,
    FileType,
    Disposition,
    ContentId,
    MimeType,
    Content,
    Bcc,
)

load_dotenv()

MAILER = SendGridAPIClient(getenv("SENDGRID_API_KEY"))
BCCS = [a for a in getenv("EMAIL_BCCS").split(";") if a]
FROM_EMAIL = (getenv("FROM_EMAIL_ADDRESS"), getenv("FROM_EMAIL_NAME"))


def send_mail(
    recipients,
    subject,
    body,
    attachment_paths=[],
    bccs=BCCS,
):
    if not hasattr(recipients, "extend"):
        recipients = [recipients]
    recipients = [(r, r) for r in recipients]

    atts = []
    for path in attachment_paths:
        with path.open("rb") as f:
            data = f.read()
            encoded = base64.b64encode(data).decode()
        att = Attachment()
        att.file_content = FileContent(encoded)
        att.file_type = FileType(filetype.guess_mime(path))
        att.file_name = FileName(path.name)
        att.disposition = Disposition("attachment")
        att.content_id = ContentId(path.name)
        atts.append(att)

    message = Mail(
        from_email=FROM_EMAIL,
        to_emails=recipients,
        subject=subject,
    )
    if bccs:
        message.bcc = [Bcc(bcc, bcc, p=0) for bcc in bccs]
    message.content = Content(MimeType.html, body)
    if atts:
        message.attachment = atts
    MAILER.send(message)


if __name__ == "__main__":
    send_mail(
        "vanwykk@gmail.com",
        "Testing",
        "This is the <b>body</b>",
        attachment_paths=[
            pathlib.Path("test.pdf"),
        ],
    )



import boto3
from dotenv import load_dotenv

import json
import os

load_dotenv()

QUEUE_URL = os.getenv("AWS_QUEUE_URL")


SESSION = boto3.Session(
    aws_access_key_id=os.getenv("AWS_ACCESS_KEY_ID"),
    aws_secret_access_key=os.getenv("AWS_SECRET_ACCESS_KEY"),
)
SQS = SESSION.resource(
    "sqs",
    region_name=os.getenv("AWS_REGION", "af-south-1"),
)
QUEUE = SQS.Queue(QUEUE_URL)


def send_data(data: str, group_id: str = "default"):
    d = json.dumps(data)
    QUEUE.send_message(MessageBody=d, MessageGroupId=group_id)


def read_data(max_number_of_messages: int = 1, timeout: int = 5, delete: bool = True):
    results = QUEUE.receive_messages(
        AttributeNames=["All"],
        MaxNumberOfMessages=max_number_of_messages,
        WaitTimeSeconds=timeout,
    )
    output = []
    for r in results:
        output.append(
            {"type": r.attributes.get("MessageGroupId", "default"), "payload": r.body}
        )
        if delete:
            r.delete()
    return output


if __name__ == "__main__":
    if 0:
        send_data({"foo": "bar"})
    if 1:
        results = read_data(max_number_of_messages=5, delete=True)
        for res in results:
            print(res)



from dotenv import load_dotenv
from pymongo import MongoClient

import os


load_dotenv()


def get_db_handler(database_name: str):
    client = MongoClient(
        host=os.getenv("MONGODB_HOST"),
        port=int(os.getenv("MONGODB_PORT")),
        username=os.getenv("MONGODB_USERNAME"),
        password=os.getenv("MONGODB_PASSWORD"),
    )
    return client[database_name]


if __name__ == "__main__":
    db = get_db_handler("md410_2024_conv")
    print(db.list_collection_names())



""" Build a PDF document from the supplied path to a markdown file and Docker container

"""
__author__ = "K van Wyk"
__version__ = "0.0.1"
import os.path
from pathlib import Path

import rich_click as click
import docker
from rich import print

CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])


def build_pdf(source: Path, image: str, pull: bool = False, debug: bool = False):
    """Read SOURCE file and write an equivalently named PDF file to SOURCE's dir by invoking docker IMAGE"""
    source = source.absolute()
    client = docker.from_env()
    volumes = {source.parent: {"bind": "/io", "mode": "rw"}}
    if pull:
        if debug:
            print(f"[yellow]Pulling {image}[/]")
        client.images.pull(image)
        if debug:
            print(f"[green]Done pulling {image}[/]")

    client.containers.run(
        image,
        name="md410_pdf_creator",
        command=f"/io/{source.name}",
        volumes=volumes,
        auto_remove=True,
        stdout=True,
        stderr=True,
        tty=False,
    ).decode("utf-8")
    fn = f"{os.path.splitext(source.name)[0]}.pdf"
    if debug:
        print(f'Built PDF of "{fn}"')
    return fn


@click.command(context_settings=CONTEXT_SETTINGS)
@click.argument(
    "source",
)
@click.argument(
    "image",
)
@click.option("--pull", is_flag=True, help="Whether to also pull a fresh image")
@click.option("--debug/--no-debug", default=True, help="Whether to output debug")
def main(source, image, pull, debug):
    build_pdf(Path(source), image, pull, debug)


if __name__ == "__main__":
    main()
